Liara ![CI passing](https://github.com/anteru/liara/actions/workflows/build.yaml/badge.svg)
![PyPi](https://img.shields.io/pypi/v/liara.svg)
=====

Liara is a static page generator written in [Python](https://python.org). See:

* The [liara website](https://liara.sh13.net) for an overview of liara. That page has been generated using liara.
* The [documentation](https://liara-web.readthedocs.io) containing the quick-start guide and more.
